@@ -31,7 +31,7 @@ use std::str::FromStr;
 use thiserror::Error;
 use typed_index_collection::{impl_id, impl_with_id, Idx, WithId};
 
-#[derive(Serialize, Deserialize, Debug, Clone, PartialEq)]
+#[derive(Serialize, Deserialize, Debug, Clone, PartialEq, Eq, Hash)]
 #[serde(rename_all = "snake_case")]
 pub enum ObjectType {
     StopArea,
@@ -334,7 +334,7 @@ impl Ord for PhysicalMode {
 
 impl PartialOrd for PhysicalMode {
     fn partial_cmp(&self, other: &PhysicalMode) -> Option<Ordering> {
-        Some(self.cmp(&other))
+        Some(self.cmp(other))
     }
 }
 
@@ -404,35 +404,16 @@ impl std::fmt::Display for Rgb {
     }
 }
 
-#[derive(Debug)]
+#[derive(Debug, Error)]
 pub enum RgbError {
+    #[error("String is not a valid Hexadecimal value")]
     NotHexa,
+    #[error("String is too long (6 characters expected)")]
     TooLongHexa,
+    #[error("String is too short (6 characters expected)")]
     TooShortHexa,
 }
 
-use std::error::Error;
-
-impl std::fmt::Display for RgbError {
-    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
-        match *self {
-            RgbError::NotHexa => f.write_str("RgbError_NotHexa"),
-            RgbError::TooLongHexa => f.write_str("RgbError_TooLongHexa"),
-            RgbError::TooShortHexa => f.write_str("RgbError_NumberOfChar"),
-        }
-    }
-}
-
-impl Error for RgbError {
-    fn description(&self) -> &str {
-        match *self {
-            RgbError::NotHexa => "String is not a valid Hexadecimal value",
-            RgbError::TooLongHexa => "String is too long (6 characters expected)",
-            RgbError::TooShortHexa => "String is too short (6 characters expected)",
-        }
-    }
-}
-
 impl FromStr for Rgb {
     type Err = RgbError;
 
@@ -746,7 +727,7 @@ impl VehicleJourney {
     }
 }
 
-#[derive(Serialize, Deserialize, Debug)]
+#[derive(Serialize, Deserialize, Debug, Clone, PartialEq, Eq, Hash)]
 pub struct Frequency {
     #[serde(rename = "trip_id")]
     pub vehicle_journey_id: String,
@@ -761,9 +742,11 @@ impl AddPrefix for Frequency {
     }
 }
 
-#[derive(Debug)]
+#[derive(Debug, Error)]
 pub enum TimeError {
+    #[error("Time format should be HH:MM:SS")]
     WrongFormat,
+    #[error("Minutes and Seconds should be in [0..59] range")]
     WrongValue,
 }
 impl From<std::num::ParseIntError> for TimeError {
@@ -771,24 +754,8 @@ impl From<std::num::ParseIntError> for TimeError {
         TimeError::WrongFormat
     }
 }
-impl std::fmt::Display for TimeError {
-    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
-        match *self {
-            TimeError::WrongFormat => f.write_str("wrong format"),
-            TimeError::WrongValue => f.write_str("wrong value"),
-        }
-    }
-}
-impl Error for TimeError {
-    fn description(&self) -> &str {
-        match *self {
-            TimeError::WrongFormat => "Time format should be HH:MM:SS",
-            TimeError::WrongValue => "Minutes and Seconds should be in [0..59] range",
-        }
-    }
-}
 
-#[derive(Debug, Default, Copy, Clone, Eq, PartialEq, Ord, PartialOrd)]
+#[derive(Debug, Default, Copy, Clone, Eq, PartialEq, Ord, PartialOrd, Hash)]
 pub struct Time(u32);
 impl Time {
     pub fn new(h: u32, m: u32, s: u32) -> Time {
@@ -918,7 +885,7 @@ impl Ord for StopTime {
 
 impl PartialOrd for StopTime {
     fn partial_cmp(&self, other: &StopTime) -> Option<Ordering> {
-        Some(self.cmp(&other))
+        Some(self.cmp(other))
     }
 }
 
@@ -1521,14 +1488,18 @@ impl Equipment {
     }
 }
 
-#[derive(Serialize, Deserialize, Debug, PartialEq, Clone)]
+#[derive(Serialize, Deserialize, Debug, Clone, Derivative)]
+#[derivative(PartialEq)]
 pub struct Transfer {
     pub from_stop_id: String,
     pub to_stop_id: String,
     #[serde(serialize_with = "ser_option_u32_with_default")]
+    #[derivative(PartialEq = "ignore")]
     pub min_transfer_time: Option<u32>,
     #[serde(serialize_with = "ser_option_u32_with_default")]
+    #[derivative(PartialEq = "ignore")]
     pub real_min_transfer_time: Option<u32>,
+    #[derivative(PartialEq = "ignore")]
     pub equipment_id: Option<String>,
 }
 
@@ -1543,6 +1514,14 @@ impl AddPrefix for Transfer {
     }
 }
 
+impl Hash for Transfer {
+    fn hash<H: Hasher>(&self, state: &mut H) {
+        (&self.from_stop_id, &self.to_stop_id).hash(state);
+    }
+}
+
+impl Eq for Transfer {}
+
 #[derive(Serialize, Deserialize, Debug, Derivative, PartialEq, Clone)]
 #[derivative(Default)]
 pub enum TransportType {
@@ -1618,7 +1597,7 @@ impl AddPrefix for Geometry {
     }
 }
 
-#[derive(Serialize, Deserialize, Debug, PartialEq)]
+#[derive(Clone, Serialize, Deserialize, Debug, PartialEq, Eq, Hash)]
 pub struct AdminStation {
     pub admin_id: String,
     pub admin_name: String,
@@ -1632,7 +1611,7 @@ impl AddPrefix for AdminStation {
     }
 }
 
-#[derive(Serialize, Deserialize, Debug, Eq, PartialEq, Ord, PartialOrd)]
+#[derive(Clone, Serialize, Deserialize, Debug, Eq, PartialEq, Ord, PartialOrd, Hash)]
 pub struct PriceV1 {
     pub id: String,
     #[serde(
@@ -1658,7 +1637,7 @@ impl AddPrefix for PriceV1 {
     }
 }
 
-#[derive(Serialize, Deserialize, Debug, PartialEq, Eq, PartialOrd, Ord)]
+#[derive(Clone, Serialize, Deserialize, Debug, Eq, PartialEq, Ord, PartialOrd, Hash)]
 pub struct OdFareV1 {
     #[serde(rename = "Origin ID")]
     pub origin_stop_area_id: String,
@@ -1685,7 +1664,7 @@ impl AddPrefix for OdFareV1 {
     }
 }
 
-#[derive(Default, Serialize, Deserialize, Debug, Eq, PartialEq, Ord, PartialOrd)]
+#[derive(Clone, Default, Serialize, Deserialize, Debug, Eq, PartialEq, Ord, PartialOrd, Hash)]
 pub struct FareV1 {
     #[serde(rename = "avant changement")]
     pub before_change: String,
@@ -1730,7 +1709,7 @@ impl AddPrefix for Ticket {
     }
 }
 
-#[derive(Serialize, Deserialize, Debug, PartialEq)]
+#[derive(Clone, Serialize, Deserialize, Debug, PartialEq, Eq, Hash)]
 pub struct TicketPrice {
     pub ticket_id: String,
     #[serde(rename = "ticket_price", deserialize_with = "de_positive_decimal")]
@@ -1777,7 +1756,7 @@ impl AddPrefix for TicketUse {
     }
 }
 
-#[derive(Serialize, Deserialize, Debug, PartialEq)]
+#[derive(Clone, Serialize, Deserialize, Debug, PartialEq, Eq, Hash)]
 pub enum PerimeterAction {
     #[serde(rename = "1")]
     Included,
@@ -1785,7 +1764,7 @@ pub enum PerimeterAction {
     Excluded,
 }
 
-#[derive(Serialize, Deserialize, Debug, PartialEq)]
+#[derive(Clone, Serialize, Deserialize, Debug, PartialEq, Eq, Hash)]
 pub struct TicketUsePerimeter {
     pub ticket_use_id: String,
     pub object_type: ObjectType,
@@ -1800,7 +1779,7 @@ impl AddPrefix for TicketUsePerimeter {
     }
 }
 
-#[derive(Serialize, Deserialize, Debug, PartialEq)]
+#[derive(Clone, Serialize, Deserialize, Debug, PartialEq, Eq, Hash)]
 pub enum RestrictionType {
     #[serde(rename = "zone")]
     Zone,
@@ -1808,7 +1787,7 @@ pub enum RestrictionType {
     OriginDestination,
 }
 
-#[derive(Serialize, Deserialize, Debug, PartialEq)]
+#[derive(Clone, Serialize, Deserialize, Debug, PartialEq, Eq, Hash)]
 pub struct TicketUseRestriction {
     pub ticket_use_id: String,
     pub restriction_type: RestrictionType,
@@ -1852,7 +1831,7 @@ impl AddPrefix for GridCalendar {
     }
 }
 
-#[derive(Debug, Serialize, Deserialize)]
+#[derive(Clone, Serialize, Deserialize, Debug, PartialEq, Eq, Hash)]
 pub struct GridExceptionDate {
     pub grid_calendar_id: String,
     #[serde(
@@ -1871,7 +1850,7 @@ impl AddPrefix for GridExceptionDate {
     }
 }
 
-#[derive(Debug, Serialize, Deserialize)]
+#[derive(Clone, Serialize, Deserialize, Debug, PartialEq, Eq, Hash)]
 pub struct GridPeriod {
     pub grid_calendar_id: String,
     #[serde(
@@ -1893,7 +1872,7 @@ impl AddPrefix for GridPeriod {
     }
 }
 
-#[derive(Debug, Serialize, Deserialize)]
+#[derive(Clone, Debug, Serialize, Deserialize, PartialEq, Eq, Hash)]
 pub struct GridRelCalendarLine {
     pub grid_calendar_id: String,
     pub line_id: String,
